@@ -301,11 +301,6 @@ impl<T> Node<T> {
 
         if let Some(pos) = self.find_static_child(path[0]) {
             let child = &self.children[pos];
-            if path == child.name {
-                if let Some(data) = child.matches(&[], params) {
-                    return Some(data);
-                }
-            }
             if let Some(tail_path) = path.strip_prefix(child.name.as_slice()) {
                 if let Some(data) = child.matches(tail_path, params) {
                     return Some(data);
